[![Build Status](https://travis-ci.com/Gawaboumga/PyMatex.svg?branch=master)](https://travis-ci.com/Gawaboumga/PyMatex) [![Coverage Status](https://coveralls.io/repos/github/Gawaboumga/PyMatex/badge.svg?branch=master)](https://coveralls.io/github/Gawaboumga/PyMatex?branch=master)

# PyMatex

Parser which allows to parse mathematical expressions written in LaTeX.
